/*******************************************************************************************
 * Logic Section - Code that captures and interprets user input
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Libraries - For special control of the phone
/////////////////////////////////////////////////////////////////////////////////////////////

import processing.phone.*;
Phone myPhone; // Named reference to your phone

/////////////////////////////////////////////////////////////////////////////////////////////
// State - Named modes of the program to make code more readable
/////////////////////////////////////////////////////////////////////////////////////////////

// Names for each possible screen
int SCREEN_MENU = 0;
int SCREEN_A = 1;
int SCREEN_B = 2;
int SCREEN_C = 3;

// Names for each possible menu focus selection
int MENU_OPTIONA = 0;
int MENU_OPTIONB = 1;
int MENU_OPTIONC = 2;

int screenMode = SCREEN_MENU;  // Overall mode of the application, start with the menu
int menuFocus = MENU_OPTIONA;  // Focus state of the menu

/////////////////////////////////////////////////////////////////////////////////////////////
// Setup - Executes only once, prepares program to run (Logic Initialization)
/////////////////////////////////////////////////////////////////////////////////////////////

void setup()
{ 
  myPhone = new Phone(this); // Creates a phone controller
  myPhone.fullscreen();      // Use the entire screen

  loadMenu();
  loadScreenA();
  loadScreenB();
  loadScreenC();
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Draw - Executes forever, provides user feedback (Logic Repetition)
/////////////////////////////////////////////////////////////////////////////////////////////

void draw()
{
  if(screenMode == SCREEN_MENU){
    drawMenu();
  } 
  else if(screenMode == SCREEN_A){
    drawScreenA();
  } 
  else if(screenMode == SCREEN_B){
    drawScreenB();
  } 
  else if(screenMode == SCREEN_C){
    drawScreenC();
  } 
}

/////////////////////////////////////////////////////////////////////////////////////////////
// KeyPressed - Executes whenever a key is pressed, captures user input (User Input)
/////////////////////////////////////////////////////////////////////////////////////////////

// KeyPressed - Executes whenever a key is pressed, captures user input (User Input)
void keyPressed()
{
  // if showing menu
  if(screenMode == SCREEN_MENU){
    // if focused on option A
    if(menuFocus == MENU_OPTIONA){
      // if pressed down
      if(keyCode == DOWN){
        menuFocus = MENU_OPTIONB; // move focus to option B
      }
      // if pressed in
      else if(keyCode == FIRE){
        screenMode = SCREEN_A; // show screen A
      }
    }
    // if focused on option B
    else if(menuFocus == MENU_OPTIONB){
      // if pressed up
      if(keyCode == UP){
        menuFocus = MENU_OPTIONA; // move focus to option A
      }
      // if pressed down
      else if(keyCode == DOWN){
        menuFocus = MENU_OPTIONC; // move focus to option C
      }
      // if pressed in
      else if(keyCode == FIRE){
        screenMode = SCREEN_B; // show screen B
      }
    }
    // if focused on option C
    else if(menuFocus == MENU_OPTIONC){
      // if pressed up
      if(keyCode == UP){
        menuFocus = MENU_OPTIONB; // move focus to option B
      }
      // if pressed in
      else if(keyCode == FIRE){
        screenMode = SCREEN_C; // show screen C
      }
    }
    // if pressed right softkey (while focused on any option)
    if(keyCode == SOFTKEY2){
      exit(); // exit application
    }
  }
  // if showing screen A
  if(screenMode == SCREEN_A){
    // if pressed left soft key
    if(keyCode == SOFTKEY2){
      screenMode = SCREEN_MENU; // show menu
    }
  }
  // if showing screen B
  if(screenMode == SCREEN_B){
    // if pressed left soft key
    if(keyCode == SOFTKEY2){
      screenMode = SCREEN_MENU; // show menu
    }
  }
  // if showing screen C
  if(screenMode == SCREEN_C){
    // if pressed left soft key
    if(keyCode == SOFTKEY2){
      screenMode = SCREEN_MENU; // show menu
    }
  }
}
