/*******************************************************************************************
 * Logic Section - Code that captures and interprets user input
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Libraries - For special control of the phone
/////////////////////////////////////////////////////////////////////////////////////////////

import processing.phone.*;
Phone myPhone; // Named reference to your phone

/////////////////////////////////////////////////////////////////////////////////////////////
// State - Named modes of the program to make code more readable
/////////////////////////////////////////////////////////////////////////////////////////////

// Names for each possible screen
final int SCREEN_MENU = 0;
final int SCREEN_A = 1;
final int SCREEN_B = 2;
final int SCREEN_C = 3;

// Names for each possible menu focus selection
final int MENU_OPTIONA = 0;
final int MENU_OPTIONB = 1;
final int MENU_OPTIONC = 2;

int screenMode = SCREEN_MENU;  // Overall mode of the application, start with the menu
int menuFocus = MENU_OPTIONA;  // Focus state of the menu

/////////////////////////////////////////////////////////////////////////////////////////////
// Setup - Executes only once, prepares program to run (Logic Initialization)
/////////////////////////////////////////////////////////////////////////////////////////////

void setup()
{ 
  myPhone = new Phone(this); // Creates a phone controller
  myPhone.fullscreen();      // Use the entire screen

    loadMenu();
  loadScreenA();
  loadScreenB();
  loadScreenC();
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Draw - Executes forever, provides user feedback (Logic Repetition)
/////////////////////////////////////////////////////////////////////////////////////////////

void draw()
{
  if(screenMode == SCREEN_MENU){
    drawMenu();
  } 
  else if(screenMode == SCREEN_A){
    drawScreenA();
  } 
  else if(screenMode == SCREEN_B){
    drawScreenB();
  } 
  else if(screenMode == SCREEN_C){
    drawScreenC();
  } 
}

/////////////////////////////////////////////////////////////////////////////////////////////
// KeyPressed - Executes whenever a key is pressed, captures user input (User Input)
/////////////////////////////////////////////////////////////////////////////////////////////

// KeyPressed - Executes whenever a key is pressed, captures user input (User Input)
void keyPressed()
{
  switch(screenMode){
  case SCREEN_MENU:
    switch(menuFocus){
    case MENU_OPTIONA:
      switch(keyCode){
      case DOWN:
        menuFocus = MENU_OPTIONB;
        break;
      case FIRE:
        screenMode = SCREEN_A;
        break;
      }
      break;
    case MENU_OPTIONB:
      switch(keyCode){
      case UP:
        menuFocus = MENU_OPTIONA;
        break;
      case DOWN:
        menuFocus = MENU_OPTIONC;
        break;
      case FIRE:
        screenMode = SCREEN_B;
        break;
      }
      break;
    case MENU_OPTIONC:
      switch(keyCode){
      case UP:
        menuFocus = MENU_OPTIONB;
        break;
      case FIRE:
        screenMode = SCREEN_C;
        break;
      }
      break;
    }
    break;
  case SCREEN_A:
    switch(keyCode){
    case SOFTKEY2:
      screenMode = SCREEN_MENU;
      break;
    }
    break;
  case SCREEN_B:
    switch(keyCode){
    case SOFTKEY2:
      screenMode = SCREEN_MENU;
      break;
    }
    break;
  case SCREEN_C:
    switch(keyCode){
    case SOFTKEY2:
      screenMode = SCREEN_MENU;
      break;
    }
    break;
  }
}
